@@ -9,12 +9,12 @@ import publication
 
 from jsii.python import classproperty
 
-import aws_cdk.assets
 import aws_cdk.aws_cloudformation
 import aws_cdk.aws_iam
 import aws_cdk.aws_lambda
 import aws_cdk.aws_s3
-import aws_cdk.cdk
+import aws_cdk.aws_s3_assets
+import aws_cdk.core
 __all__ = []
 
 publication.publish()
